@@ -1,4 +1,3 @@
-from __future__ import absolute_import
 from spidermon.exceptions import NotConfigured
 
 from . import CreateReport
@@ -8,14 +7,14 @@ class CreateFileReport(CreateReport):
     filename = None
 
     def __init__(self, filename, *args, **kwargs):
-        super(CreateFileReport, self).__init__(*args, **kwargs)
+        super().__init__(*args, **kwargs)
         self.filename = filename or self.filename
         if not self.filename:
             raise NotConfigured("You must define a template output file.")
 
     @classmethod
     def from_crawler_kwargs(cls, crawler):
-        kwargs = super(CreateFileReport, cls).from_crawler_kwargs(crawler)
+        kwargs = super().from_crawler_kwargs(crawler)
         kwargs.update({"filename": crawler.settings.get("SPIDERMON_REPORT_FILENAME")})
         return kwargs
 
