@@ -9,7 +9,7 @@ from scrapy.utils.project import data_path
 class LocalStorageStatsHistoryCollector(StatsCollector):
     def _stats_location(self, spider):
         statsdir = data_path("stats", createdir=True)
-        return os.path.join(statsdir, "{}_stats_history".format(spider.name))
+        return os.path.join(statsdir, f"{spider.name}_stats_history")
 
     def open_spider(self, spider):
         stats_location = self._stats_location(spider)
