@@ -1,11 +1,9 @@
-from __future__ import absolute_import
-import six
 import ast
 
 from spidermon.exceptions import InvalidExpression
 
 
-class Interpreter(object):
+class Interpreter:
 
     ast_allowed_nodes = (
         "expr",
@@ -68,7 +66,7 @@ class Interpreter(object):
 
     allowed_objects = (
         str,
-        six.text_type,  # strings
+        str,  # strings
         int,
         float,
         complex,  # numbers
@@ -81,7 +79,7 @@ class Interpreter(object):
     )
 
     def check(self, expression):
-        if not isinstance(expression, six.string_types):
+        if not isinstance(expression, str):
             raise InvalidExpression("Python expressions must be defined as strings")
         if not expression:
             raise InvalidExpression("Empty python expression")
